searchData={"content_type":"text/markdown","items":[{"doc":"An Elixir library for using Redis locks","ref":"RedisMutex.html","title":"RedisMutex","type":"module"},{"doc":"1. Add `redis_mutex` to your list of dependencies in `mix.exs`:\n\n  ```elixir\n  def deps do\n    [{:redis_mutex, \"~> 0.4.0\"}]\n  end\n  ```\n\n2. Ensure `redis_mutex` is started before your application:\n\n  ```elixir\n  def application do\n    [applications: [:redis_mutex]]\n  end\n  ```\n\n3. Set the `redis_url` in your `config.exs`\n\n  ```elixir\n  config :redis_mutex, redis_url: {:system, \"REDIS_URL\"}\n  ```\n\n4. Call `use RedisMutex` in the module you want to use the lock.\n\n  ```elixir\n  defmodule PossumLodge do\n\n    def get_oath do\n      \"Quando omni flunkus moritati\"\n    end\n  end\n  ```\n\n  With a Redis lock:\n\n  ```elixir\n  defmodule PossumLodge do\n    use RedisMutex\n\n    def get_oath do\n      with_lock(\"my_key\") do\n        \"Quando omni flunkus moritati\"\n      end\n    end\n  end\n  ```","ref":"RedisMutex.html#module-setup","title":"Setup - RedisMutex","type":"module"},{"doc":"Instead of passing a `redis_url` to configure the `Redix` client, use `redix_config`\nto pass any of the [configuration options available to Redix](https://hexdocs.pm/redix/Redix.html#start_link/1-options):\n\n```elixir\nconfig :redis_mutex,\n  redix_config: [\n    host: \"example.com\",\n    port: 9999,\n    ssl: true,\n    socket_opts: [\n      customize_hostname_check: [\n        match_fun: :public_key.pkix_verify_hostname_match_fun(:https)\n      ]\n    ]\n  ]\n\nOnly one of `:redix_config` and `:redis_url` can be used at a time.","ref":"RedisMutex.html#module-custom-redix-configuration","title":"Custom Redix configuration - RedisMutex","type":"module"},{"doc":"This module connects to the Redis instance.","ref":"RedisMutex.Connection.html","title":"RedisMutex.Connection","type":"module"},{"doc":"","ref":"RedisMutex.Connection.html#child_spec/1","title":"RedisMutex.Connection.child_spec/1","type":"function"},{"doc":"","ref":"RedisMutex.Connection.html#start_link/2","title":"RedisMutex.Connection.start_link/2","type":"function"},{"doc":"This module contains the actual Redis locking business logic. The `with_lock`\nmacro is generally the only function that should be used from this module, as it\nwill handle the logic for setting and removing key/values in Redis.","ref":"RedisMutex.Lock.html","title":"RedisMutex.Lock","type":"module"},{"doc":"This function takes in a key and a unique identifier to set it in Redis.\nThis is how a lock is identified in Redis. If a key/value pair is able to be\nset in Redis, `lock` returns `true`. If it isn't able to set in Redis, `lock`\nreturns `false`.","ref":"RedisMutex.Lock.html#lock/3","title":"RedisMutex.Lock.lock/3","type":"function"},{"doc":"This function takes in a key, unique string, and a timeout in milliseconds.\nIt will call itself recursively until it is able to set a lock\nor the timeout expires.","ref":"RedisMutex.Lock.html#take_lock/5","title":"RedisMutex.Lock.take_lock/5","type":"function"},{"doc":"This function takes in the key/value pair that are to be released in Redis","ref":"RedisMutex.Lock.html#unlock/2","title":"RedisMutex.Lock.unlock/2","type":"function"},{"doc":"This macro takes in a key and a timeout.\n\n  A key might be be an id or a resource identifier that will\n  lock a particular resource. A good example might be an email or phone\n  number for a user, and you might want lock a db insert so that\n  multiple users aren't created for one email or phone number.\n\n  The timeout is in milliseconds and defaults to 40000 milliseconds.\n  There is a key expiration of 20 seconds, so the timeout should always\n  be greater than 20 seconds. The 20 second expiry allows the key to expire\n  in case the logic inside the `with_lock` macro throws an error or fails\n  to complete within 20 seconds, thereby freeing up the key so the lock\n  can be obtained by another request or resource.\n\n  The lock will be released after the logic inside the `with_lock` has\n  completed, or the timeout, whichever comes first. The return value\n  of the macro will be the return value of the logic inside\n  the 'with_lock' macro.\n\n  ```elixir\n  defmodule PossumLodge do\n    use RedisMutex\n    alias PossumLodge.{Repo, Member}\n\n    def add_member(params) do\n      with_lock(params.phone_number) do\n        %Member{}\n        |> Member.changeset(params)\n        |> Repo.insert_or_update!\n      end\n    end\n  end\n  ```","ref":"RedisMutex.Lock.html#with_lock/4","title":"RedisMutex.Lock.with_lock/4","type":"macro"},{"doc":"","ref":"RedisMutex.Error.html","title":"RedisMutex.Error","type":"exception"},{"doc":"# RedisMutex\n\n[![Build Status](https://github.com/podium/redis_mutex/actions/workflows/ci.yml/badge.svg)](https://github.com/podium/redis_mutex/actions/workflows/ci.yml) [![Hex.pm](https://img.shields.io/hexpm/v/redis_mutex.svg)](https://hex.pm/packages/redis_mutex) [![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/redis_mutex)\n[![Total Download](https://img.shields.io/hexpm/dt/redis_mutex.svg)](https://hex.pm/packages/redis_mutex)\n[![License](https://img.shields.io/hexpm/l/redis_mutex.svg)](https://github.com/podium/redis_mutex/blob/master/LICENSE.md)\n\nRedisMutex is a library for creating a Redis lock for a single Redis instance.","ref":"readme.html","title":"Readme","type":"extras"},{"doc":"The package can be installed by adding `redis_mutex`\nto your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:redis_mutex, \"~> 0.4.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Readme","type":"extras"},{"doc":"1. Set the `redis_url` in your `config.exs`\n\n```elixir\nconfig :redis_mutex, redis_url: {:system, \"REDIS_URL\"}\n```\n\nAlternatively, pass [`redix` options](https://hexdocs.pm/redix/Redix.html#start_link/1-options) directly:\n\n```elixir\nconfig :redis_mutex,\n  redix_config: [\n    host: \"example.com\",\n    port: 9999,\n    ssl: true,\n    socket_opts: [\n      customize_hostname_check: [\n        match_fun: :public_key.pkix_verify_hostname_match_fun(:https)\n      ]\n    ]\n  ]\n\n2. Call `use RedisMutex` in the module you want to use the lock and use `with_lock` to\nlock critical parts of your code.\n\n```elixir\ndefmodule PossumLodge do\n  use RedisMutex\n\n  def get_oauth do\n    with_lock(\"my_key\") do\n      \"Quando omni flunkus moritati\"\n    end\n  end\nend\n```","ref":"readme.html#usage","title":"Usage - Readme","type":"extras"},{"doc":"To run the portion of the test suite that does not rely on Redis, run the default command:\n```\nmix test\n```\n\nTo run the full test suite including those portions that depend on a Redis instance running\nand being configured in `config/test.exs`, run the following command:\n```\nREDIS_TESTS=true mix test --include=redis_dependent\n```","ref":"readme.html#tests","title":"Tests - Readme","type":"extras"},{"doc":"# CHANGELOG","ref":"changelog.html","title":"CHANGELOG","type":"extras"},{"doc":"#","ref":"changelog.html#0-6-0-2023-11-08","title":"0.6.0 (2023-11-08) - CHANGELOG","type":"extras"},{"doc":"- support for Elixir 1.15. Bump some package dependencies\n- change to use Uniq lib rather than the unmaintained elixir_uuid","ref":"changelog.html#changed","title":"Changed - CHANGELOG","type":"extras"},{"doc":"#","ref":"changelog.html#0-5-0-2023-08-16","title":"0.5.0 (2023-08-16) - CHANGELOG","type":"extras"},{"doc":"* Support custom redix opts by @brentjanderson (#23)\n* Updates some of the dependencies","ref":"changelog.html#changed","title":"Changed - CHANGELOG","type":"extras"},{"doc":"#","ref":"changelog.html#0-4-0-2022-11-22","title":"0.4.0 (2022-11-22) - CHANGELOG","type":"extras"},{"doc":"* Use Redix instead of ExRedis as the adapter\n* Bump Elixir version to 1.11\n* Retool the internals of the library to use modern Elixir conventions\n* Updates to the test suite so it can run against live redis in test","ref":"changelog.html#changed","title":"Changed - CHANGELOG","type":"extras"}]}